antiSMASH object model
======================
![Run tests](https://github.com/antismash/models/workflows/Run%20tests/badge.svg)

An object model for mapping antiSMASH data objects from and to Redis via aioredis.


License
-------

Under the same GNU AGPL v3 or later license as the rest of antiSMASH.
See [`LICENSE.txt`](LICENSE.txt) for details.
